"""Game Collection - A collection of classic arcade games."""

__version__ = "1.0.1"
__author__ = "Game Collection Team"
__email__ = "game-collection@example.com"

from .main import main

__all__ = ["main", "__version__"]
